# -*- coding: utf-8

from __future__ import unicode_literals

from django.conf import settings

DANDELION_HOST = getattr(settings, 'DANDELION_HOST', 'api.dandelion.eu')
DANDELION_TOKEN = getattr(settings, 'DANDELION_TOKEN', None)
DANDELION_USE_CACHE = getattr(settings, 'DANDELION_USE_CACHE', True)



# -*- coding: utf-8

from __future__ import unicode_literals


class DandelionException(Exception):
    def __init__(self, message, **kwargs):
        self.message = message
        self.code = kwargs.get('code')
        self.data = kwargs.get('data')

        super(DandelionException, self).__init__(self.message)


class DandelionSettingsException(Exception):
    """Raised when settings be bad."""



# -*- coding: utf-8

from __future__ import unicode_literals

import requests
import hashlib

from django.core.cache import cache

from . import __version__
from .conf import DANDELION_HOST, DANDELION_TOKEN, DANDELION_USE_CACHE
from .exceptions import DandelionException


class AttributeDict(dict):
    def __getattr__(self, name):
        return self[name]

    def __setattr__(self, name, value):
        self[name] = value

    def __delattr__(self, name):
        del self[name]


class BaseDandelionRequest(object):
    def __init__(self):
        self.__requests = requests.session()
        self.__uri = DANDELION_HOST if DANDELION_HOST.startswith('http') else 'https://' + DANDELION_HOST

    def _do_request(self, extra_url='', method='post', extra_dict=None, use_cache=False):
        if extra_dict is None:
            params = {}
        else:
            params = extra_dict.copy()
        params['token'] = DANDELION_TOKEN

        url = self.__uri + ''.join('/' + x for x in extra_url)

        cache_key = self.__cache_get_key_for(url=url, params=params, method=method)
        if cache.get(cache_key) and use_cache:
            response = cache.get(cache_key)
        else:
            response = self.__do_raw_request(url, params, method)
            if response.ok and use_cache:
                cache.set(cache_key, response)

        obj = response.json(object_hook=AttributeDict)
        if not response.ok:
            raise DandelionException(message=obj.message, code=obj.code, data=obj.data)

        return obj

    def __do_raw_request(self, url, params, method):
        kwargs = {
            'data' if method in ('post', 'put') else 'params': params,
            'url': url,
            'headers': {
                'User-Agent': 'django-dandelion/' + __version__
            }
        }

        return getattr(self.__requests, method)(**kwargs)

    @staticmethod
    def __cache_get_key_for(**kwargs):
        input_s = ''
        for key in sorted(kwargs):
            input_s += u'{}={},'.format(key, kwargs[key])
        input_s = input_s.encode('utf-8')
        return 'dandelion_' + hashlib.sha1(input_s).hexdigest()


class BaseDandelionParamsRequest(BaseDandelionRequest):
    def __init__(self, keys_allowed, keys_unique, **params):
        self.__keys_allowed = keys_allowed
        self.__keys_unique = keys_unique

        self.__params = params
        for key in params:
            self.__validate_param(key)

        super(BaseDandelionParamsRequest, self).__init__()

    def _do_request(self, extra_url='', method='post', extra_dict=None, use_cache=DANDELION_USE_CACHE):
        return super(BaseDandelionParamsRequest, self)._do_request(
            extra_url=extra_url,
            method=method,
            extra_dict=self.__params,
            use_cache=use_cache
        )

    def __validate_param(self, key):
        if key not in self.__keys_allowed:
            raise DandelionException(message='Key not allowed; you can use the following keys: {}'.format(
                ', '.join(self.__keys_allowed)))

        for keys in self.__keys_unique:
            if key in keys:
                temp = set(keys)
                temp.discard(key)
                intersection = list(set(self.__params.keys()) & temp)
                if len(intersection) > 0:
                    self.__params_remove_key(intersection[0])

    @property
    def params(self):
        return self.__params

    @params.setter
    def params(self, value):
        if not isinstance(value, (list, set, tuple)) or len(value) != 2:
            raise DandelionException(message='Two inputs are required: key and value')

        self.__validate_param(value[0])
        self.__params[value[0]] = value[1]

    @params.deleter
    def params(self):
        self.__params = {}

    def __params_remove_key(self, key):
        del self.__params[key]

    def analyze(self):
        raise NotImplementedError



# -*- coding: utf-8

from __future__ import unicode_literals

from .base import BaseDandelionParamsRequest


class Wikisearch(BaseDandelionParamsRequest):
    """
    Looking for Wikipedia pages but don't know their exact title? We can help you to search for the page you want.
    You can also test Wikisearch from the demo page, at wikisearch.dandelion.eu

    https://dandelion.eu/docs/api/datagraph/wikisearch/
    """

    def __init__(self, **params):
        """
        :param params:
            text = A string that you want to be matched against Wikipedia.
                | required
                | Type: string
                | Example: text=tower of big ben
            lang = The language of the string to be searched; currently English, French, German, Italian, Portuguese
                and Spanish are supported.
                | required
                | Type: string
                | Default value: en
                | Accepted values: de | en | es | fr | it | pt
            limit = Restricts the output to the first N results.
                | optional
                | Type: integer
                | Default value: 10
                | Accepted values: 1 .. 50
            offset = Starts listing the results from the given index. Mostly used in combination with limit parameter,
                for pagination purposes.
                | optional
                | Type: integer
                | Default value: 0
            query = With this parameter you can choose the behaviour of the search.
                If you want to search for all the entities that:
                - contain the text: use full;
                - start with the text: use prefix
                The prefix option is very useful in autocomplete scenarios.
                | optional
                | Type: string
                | Default value: full
                | Accepted values: full | prefix
            include = Returns more information on annotated entities:
                - "types" adds type information from DBpedia or dandelion. DBpedia types are extracted based on the
                  lang parameter (e.g. if lang=en, types are extracted from DBpedia english).
                  Please notice that different DBpedia instances may contain different types for the same resource;
                - "categories" adds category information from DBpedia/Wikipedia;
                - "abstract" adds the text of the Wikipedia abstract;
                - "image" adds a link to an image depicting the tagged entity, as well as a link to the image
                  thumbnail, served by Wikipedia. Please check the licensing terms of each image on Wikipedia before
                  using it in your app;
                - "lod" adds links to equivalent (sameAs) entities in Linked Open Data repositories or other websites.
                  It currently only supports DBpedia and Wikipedia;
                - "alternate_labels" adds some other names used when referring to the entity.
                | optional
                | Type: comma-separated list
                | Default value: <empty string>
                | Accepted values: types, categories, abstract, image, lod, alternate_labels
                | Example: include=types,lod
        """

        keys_allowed = [
            'text',
            'lang',
            'limit',
            'offset',
            'query',
            'include',
        ]

        super(Wikisearch, self).__init__(keys_allowed=keys_allowed, keys_unique=[[]], **params)

    def analyze(self):
        return self._do_request(
            extra_url=('datagraph', 'wikisearch', 'v1'),
            method='post'
        )



# -*- coding: utf-8

from __future__ import unicode_literals

from .base import BaseDandelionRequest, BaseDandelionParamsRequest


class EntityExtraction(BaseDandelionParamsRequest):
    """
    This is a named entity extraction & linking API that performs very well even on short texts, on which many other
    similar services do not. It currently works on English, French, German, Italian, Portuguese and Spanish texts.
    With this API you will be able to automatically tag your texts, extracting Wikipedia entities and enriching your
    data.

    https://dandelion.eu/docs/api/datatxt/nex/v1/
    """

    def __init__(self, **params):
        """
        :param params:
            text|url|html|html_fragment = These parameters define how you send text to the Entity Extraction API.
                Only one of them can be used in each request, following these guidelines:
                - use "text" when you have plain text that doesn't need any pre-processing;
                - use "url" when you have an URL and you want the Entity Extraction API to work on its main content;
                  it will fetch the URL for you, and use an AI algorithm to extract the relevant part of the document
                  to work on; in this case, the main content will also be returned by the API to allow you to properly
                  use the annotation offsets;
                - use "html" when you have an HTML document and you want the Entity Extraction API to work on its main
                  content, similarly to what the "url" parameter does.
                - use "html_fragment" when you have an HTML snippet and you want the Entity Extraction API to work on
                  its content. It will remove all HTML tags before analyzing it.
                | required
                | Type: string
            lang = The language of the text to be annotated; currently English, French, German, Italian, Portuguese and
                Spanish are supported.
                | optional
                | Type: string
                | Default value: auto
                | Accepted values: de | en | es | fr | it | pt | auto
            min_confidence = The threshold for the confidence value; entities with a confidence value below this
                threshold will be discarded. Confidence is a numeric estimation of the quality of the annotation, which
                ranges between 0 and 1. A higher threshold means you will get less but more precise annotations.
                A lower value means you will get more annotations but also more erroneous ones.
                | optional
                | Type: float
                | Default value: 0.6
                | Accepted values: 0.0 .. 1.0
            min_length = With this parameter you can remove those entities having a spot shorter than a minimum length.
                | optional
                | Type: integer
                | Default value: 2
                | Accepted values: 2 .. +inf
            social.hashtag = With this parameter you enable special hashtag parsing to correctly analyze tweets and
                facebook posts.
                | optional
                | Type: boolean
                | Default value: False
                | Accepted values: True | False
            social.mention = With this parameter you enable special mention parsing to correctly analyze tweets and
                facebook posts.
                | optional
                | Type: boolean
                | Default value: False
                | Accepted values: True | False
            include = Returns more information on annotated entities:
                - "types" adds type information from DBpedia or dandelion. DBpedia types are extracted based on the
                  lang parameter (e.g. if lang=en, types are extracted from DBpedia english). Please notice that
                  different DBpedia instances may contain different types for the same resource;
                - "categories" adds category information from DBpedia/Wikipedia;
                - "abstract" adds the text of the Wikipedia abstract;
                - "image" adds a link to an image depicting the tagged entity, as well as a link to the image
                  thumbnail, served by Wikipedia. Please check the licensing terms of each image on Wikipedia before
                  using it in your app;
                - "lod" adds links to equivalent (sameAs) entities in Linked Open Data repositories or other websites.
                  It currently only supports DBpedia and Wikipedia;
                - "alternate_labels" adds some other names used when referring to the entity.
                | optional
                | Type: comma-separated list
                | Default value: <empty string>
                | Accepted values: types, categories, abstract, image, lod, alternate_labels
                | Example: include=types,lod
            extra_types = Returns more information on annotated entities:
                - "phone" enables matching of phone numbers;
                - "vat" enables matching of VAT IDs (Italian only).
                Note that these parameters require the country parameter to be set, and VAT IDs will work only for
                Italy.
                | optional
                | Type	comma-separated list
                | Default value: <empty string>
                | Accepted values: phone, vat
                | Example: extra_types=phone,vat
            country = This parameter specifies the country which we assume VAT and telephone numbers to be coming from.
                This is important to get correct results, as different countries may adopt different formats.
                | optional
                | Type: string
                | Default value: <empty string>
                | Accepted values: AD, AE, AM, AO, AQ, AR, AU, BB, BR, BS, BY, CA, CH, CL, CN, CX, DE, FR, GB, HU, IT,
                                   JP, KR, MX, NZ, PG, PL, RE, SE, SG, US, YT, ZW
            custom_spots = Enable specific user-defined spots to be used when annotating the text.
                You can define your own spots or use someone else's ones if they shared the spots-ID with you.
                | optional
                | Type	string
                | Default value: <empty string>
                | Accepted values: any valid spots-ID

        """

        keys_allowed = [
            'text', 'url', 'html', 'html_fragment',
            'lang',
            'min_confidence',
            'min_length',
            'social.hashtag',
            'social.mention',
            'include',
            'extra_types',
            'country',
            'custom_spots',
        ]
        keys_unique = [
            ['text', 'url', 'html', 'html_fragment'],
        ]

        super(EntityExtraction, self).__init__(keys_allowed=keys_allowed, keys_unique=keys_unique, **params)

    def analyze(self):
        return self._do_request(
            extra_url=('datatxt', 'nex', 'v1'),
            method='post'
        )


class TextSimilarity(BaseDandelionParamsRequest):
    """
    This API is a semantic sentence similarity API optimized on short sentences.
    With this API you will be able to compare two sentences and get a score of their semantic similarity.
    It works even if the two sentences don't have any word in common.

    https://dandelion.eu/docs/api/datatxt/sim/v1/
    """

    def __init__(self, **params):
        """
        :param params:
            text1|url1|html1|html_fragment1 = These parameters define how you send to the Text Similarity API the first
                text you want to compare. Only one of them can be used in each request, following these guidelines:
                - use "text" when you have plain text that doesn't need any pre-processing;
                - use "url" when you have an URL and you want the Text Similarity API to work on its main content;
                  it will fetch the URL for you, and use an AI algorithm to extract the relevant part of the document
                  to work on; in this case, the main content will also be returned by the API to allow you to properly
                  use the annotation offsets;
                - use "html" when you have an HTML document and you want the Text Similarity API to work on its main
                  content, similarly to what the "url" parameter does.
                - use "html_fragment" when you have an HTML snippet and you want the Text Similarity API to work on its
                  content. It will remove all HTML tags before analyzing it.
                | required
                | Type: string
            text2|url2|html2|html_fragment2 = These parameters define how you send to the Text Similarity API the
                second text you want to compare, in the same way as the text1|url1|html1|html_fragment1 parameters.
                | required
                | Type: string
            lang = The language of the texts to be compared; currently English, French, German, Italian, Portuguese and
                Spanish are supported. Leave this parameter out to let the Text Similarity API automatically detect the
                language for you.
                | optional
                | Type: string
                | Default value: auto
                | Accepted values: de | en | es | fr | it | pt | auto
            bow = The Text Similarity API normally uses a semantic algorithm for computing similarity of texts.
                It is possible, however, to use a more classical syntactic algorithm where the semantic one fails.
                This can be done with this parameter.
                - "never" uses always the semantic algorithm;
                - "both_empty" uses the syntactic algorithm if both the two texts have no semantic information;
                - "one_empty" uses the syntactic algorithm if at least one of the two inputs have no semantic
                  information;
                - "always" uses always the syntactic algorithm.
                | optional
                | Type: string
                | Default value: never
                | Accepted values: always | one_empty | both_empty | never
            nex.min_confidence = The threshold for the confidence value; entities with a confidence value below this
                threshold will be discarded. Confidence is a numeric estimation of the quality of the annotation, which
                ranges between 0 and 1. A higher threshold means you will get less but more precise annotations.
                A lower value means you will get more annotations but also more erroneous ones.
                | optional
                | Type: float
                | Default value: 0.6
                | Accepted values: 0.0 .. 1.0
            nex.min_length = With this parameter you can remove those entities having a spot shorter than a minimum
                length.
                | optional
                | Type: integer
                | Default value: 2
                | Accepted values: 2 .. +inf
            nex.social.hashtag = With this parameter you enable special hashtag parsing to correctly analyze tweets and
                facebook posts.
                | optional
                | Type: boolean
                | Default value: False
                | Accepted values: True | False
            nex.social.mention = With this parameter you enable special mention parsing to correctly analyze tweets and
                facebook posts.
                | optional
                | Type: boolean
                | Default value: False
                | Accepted values: True | False
            nex.include = Returns more information on annotated entities:
                - "types" adds type information from DBpedia or dandelion. DBpedia types are extracted based on the
                  lang parameter (e.g. if lang=en, types are extracted from DBpedia english). Please notice that
                  different DBpedia instances may contain different types for the same resource;
                - "categories" adds category information from DBpedia/Wikipedia;
                - "abstract" adds the text of the Wikipedia abstract;
                - "image" adds a link to an image depicting the tagged entity, as well as a link to the image
                  thumbnail, served by Wikipedia. Please check the licensing terms of each image on Wikipedia before
                  using it in your app;
                - "lod" adds links to equivalent (sameAs) entities in Linked Open Data repositories or other websites.
                  It currently only supports DBpedia and Wikipedia;
                - "alternate_labels" adds some other names used when referring to the entity.
                | optional
                | Type: comma-separated list
                | Default value: <empty string>
                | Accepted values: types, categories, abstract, image, lod, alternate_labels
                | Example: include=types,lod
            nex.extra_types = Returns more information on annotated entities:
                - "phone" enables matching of phone numbers;
                - "vat" enables matching of VAT IDs (Italian only).
                Note that these parameters require the country parameter to be set, and VAT IDs will work only for
                Italy.
                | optional
                | Type	comma-separated list
                | Default value: <empty string>
                | Accepted values: phone, vat
                | Example: extra_types=phone,vat
            nex.country = This parameter specifies the country which we assume VAT and telephone numbers to be coming
                from.
                This is important to get correct results, as different countries may adopt different formats.
                | optional
                | Type: string
                | Default value: <empty string>
                | Accepted values: AD, AE, AM, AO, AQ, AR, AU, BB, BR, BS, BY, CA, CH, CL, CN, CX, DE, FR, GB, HU, IT,
                                   JP, KR, MX, NZ, PG, PL, RE, SE, SG, US, YT, ZW
            nex.custom_spots = Enable specific user-defined spots to be used when annotating the text.
                You can define your own spots or use someone else's ones if they shared the spots-ID with you.
                | optional
                | Type	string
                | Default value: <empty string>
                | Accepted values: any valid spots-ID
        """

        keys_allowed = [
            'text1', 'url1', 'html1', 'html_fragment1',
            'text2', 'url2', 'html2', 'html_fragment2',
            'lang',
            'bow',
            'nex.min_confidence',
            'nex.min_length',
            'nex.social.hashtag',
            'nex.social.mention',
            'nex.include',
            'nex.extra_types',
            'nex.country',
            'nex.custom_spots',
        ]
        keys_unique = [
            ['text1', 'url1', 'html1', 'html_fragment1'],
            ['text2', 'url2', 'html2', 'html_fragment2'],
        ]

        super(TextSimilarity, self).__init__(keys_allowed=keys_allowed, keys_unique=keys_unique, **params)

    def analyze(self):
        return self._do_request(
            extra_url=('datatxt', 'sim', 'v1'),
            method='post'
        )


class TextClassification(BaseDandelionParamsRequest):
    """
    This API classifies short documents into a set of user-defined classes. It's a very powerful and customizable tool
    for text classification, and defining your own models will take you just a couple of minutes.
    Curious? Read below how to call the Text Classification API, or discover how to define custom models.

    https://dandelion.eu/docs/api/datatxt/cl/v1/
    """

    def __init__(self, **params):
        """
        :param params:
            text|url|html|html_fragment = These parameters define how you send to the Text Classification API the text
                you want to classify. Only one of them can be used in each request, following these guidelines:
                - use "text" when you have plain text that doesn't need any pre-processing;
                - use "url" when you have an URL and you want the Text Classification API to work on its main content;
                  il will fetch the URL for you, and use an AI algorithm to extract the relevant part of the document
                  to work on; in this case, the main content will also be returned by the API to allow you to properly
                  use the annotation offsets;
                - use "html" when you have an HTML document and you want Text Classification API to work on its main
                  content, similarly to what the "url" parameter does.
                - use "html_fragment" when you have an HTML snippet and you want the Text Classification API to work on
                  its content. It will remove all HTML tags before analyzing it.
                | required
                | Type: string
            model = The unique ID of the model you want to use. If you want to learn how to manage your custom models,
                please refer to User-defined classifiers.
                | required
            min_score = return those categories that get a score above this threshold. There is not a gold-value for
                such parameter that works for every model, moreover it really depends on your use-case.
                Start experimenting with 0.25 and increase / decrease it depending on the results.
                | optional
                | Type: float
                | Default value: 0.0
                | Accepted values: 0.0 .. 1.0
            max_annotations = The Text Classification API uses the Entity Extraction API under the hood.
                With this parameter you can limit the number of annotations to be used for classifying the text, using
                only the top-most entities by their confidence.
                | optional
                | Type: integer
                | Default value: +inf
                | Accepted values: 1 .. +inf
            include = Returns more information about the classification process:
                - "score_details": we added this parameter for debug purposes: it will output, for each entity in the
                  model categories, a weight value that represents how much they have influenced the overall score of
                  their category. For each category, the weights sum up to 1.
                  Pay attention: This parameter can be used only by the model owner. You can share your models with
                  other users simply sending them the model ID, but they won't be able to use include=score_details.
                | optional
                | Type: string
                | Default value: <empty string>
                | Accepted values: score_details
                | Example: include=score_details
        """

        keys_allowed = [
            'text', 'url', 'html', 'html_fragment',
            'model',
            'min_score',
            'max_annotations',
            'include',
        ]
        keys_unique = [
            ['text', 'url', 'html', 'html_fragment'],
        ]

        super(TextClassification, self).__init__(keys_allowed=keys_allowed, keys_unique=keys_unique, **params)

    def analyze(self):
        return self._do_request(
            extra_url=('datatxt', 'cl', 'v1'),
            method='post'
        )

    class UserDefinedClassifiers(BaseDandelionRequest):
        def create(self, data):
            return self._do_request(
                extra_url=('datatxt', 'cl', 'models', 'v1'),
                method='post',
                extra_dict={'data': data}
            )

        def read(self, id):
            return self._do_request(
                extra_url=('datatxt', 'cl', 'models', 'v1'),
                method='get',
                extra_dict={'id': id}
            )

        def update(self, id, data):
            return self._do_request(
                extra_url=('datatxt', 'cl', 'models', 'v1'),
                method='put',
                extra_dict={'id': id, 'data': data}
            )

        def delete(self, id):
            return self._do_request(
                extra_url=('datatxt', 'cl', 'models', 'v1'),
                method='delete',
                extra_dict={'id': id}
            )

        def list(self):
            return self._do_request(
                extra_url=('datatxt', 'cl', 'models', 'v1'),
                method='get'
            )


class LanguageDetection(BaseDandelionParamsRequest):
    """
    Language Detection API is a simple language identification API; it is a tool that may be useful when dealing with
    texts, so we decided to open it to all our users. It currently supports 96 languages.

    https://dandelion.eu/docs/api/datatxt/li/v1/
    """

    def __init__(self, **params):
        """
        :param params:
            text|url|html|html_fragment = These parameters define how you send to the Language Detection API the
                text for which you want the language to be recognized. Only one of them can be used in each request,
                following these guidelines:
                - use "text" when you have plain text that doesn't need any pre-processing;
                - use "url" when you have an URL and you want the Language Detection API to work on its main content;
                  it will fetch the URL for you, and use an AI algorithm to extract the relevant part of the document
                  to work on; in this case, the main content will also be returned by the API to allow you to properly
                  use the annotation offsets;
                - use "html" when you have an HTML document and you want the Language Detection API to work on its main
                  content, similarly to what the "url" parameter does.
                - use "html_fragment" when you have an HTML snippet and you want the Language Detection API to work on
                  its content. It will remove all HTML tags before analyzing it.
                | required
                | Type: string
            clean = Set this parameter to true if you want the text to be cleaned from urls, email addresses, hashtags,
                and more, before being processed.
                | optional
                | Type: boolean
                | Default value: False
                | Accepted values: True | False

        """

        keys_allowed = [
            'text', 'url', 'html', 'html_fragment',
            'clean',
        ]
        keys_unique = [
            ['text', 'url', 'html', 'html_fragment'],
        ]

        super(LanguageDetection, self).__init__(keys_allowed=keys_allowed, keys_unique=keys_unique, **params)

    def analyze(self):
        return self._do_request(
            extra_url=('datatxt', 'li', 'v1'),
            method='post'
        )


class SentimentAnalysis(BaseDandelionParamsRequest):
    """
    This API analyses a text and tells whether the expressed opinion is positive, negative, or neutral.
    Given a short sentence, it returns a label representing the identified sentiment, along with a numeric score
    ranging from strongly positive (1.0) to extremely negative (-1.0).

    https://dandelion.eu/docs/api/datatxt/sent/v1/
    """

    def __init__(self, **params):
        """
        :param params:
            text|url|html|html_fragment = These parameters define how you send to the Sentiment Analysis API the text
                you want to analyze. Only one of them can be used in each request, following these guidelines:
                - use "text" when you have plain text that doesn't need any pre-processing;
                - use "url" when you have an URL and you want the Sentiment Analysis API to work on its main content;
                  it will fetch the URL for you, and use an AI algorithm to extract the relevant part of the document
                  to work on;
                - use "html" when you have an HTML document and you want the Sentiment Analysis API to work on its main
                  content, similarly to what the "url" parameter does.
                - use "html_fragment" when you have an HTML snippet and you want the Sentiment Analysis API to work on
                  its content. It will remove all HTML tags before analyzing it.
                | required
                | Type: string
            lang = The language of the text to be annotated; currently only English and Italian are supported.
                Leave this parameter out to let the Sentiment Analysis API automatically detect the language for you.
                | optional
                | Type: string
                | Default value: auto
                | Accepted values: en | it | auto
        """

        keys_allowed = [
            'text', 'url', 'html', 'html_fragment',
            'lang',
        ]
        keys_unique = [
            ['text', 'url', 'html', 'html_fragment'],
        ]

        super(SentimentAnalysis, self).__init__(keys_allowed=keys_allowed, keys_unique=keys_unique, **params)

    def analyze(self):
        return self._do_request(
            extra_url=('datatxt', 'sent', 'v1'),
            method='post'
        )



# -*- coding: utf-8

from __future__ import unicode_literals

from django.apps import AppConfig

from .conf import DANDELION_HOST, DANDELION_TOKEN
from .exceptions import DandelionSettingsException


class DandelionConfig(AppConfig):
    name = 'django_dandelion'
    label = 'django_dandelion'
    verbose_name = 'Django Dandelion'

    def ready(self):
        if not DANDELION_HOST:
            raise DandelionSettingsException('You must set DANDELION_HOST in settings.py.')
        if not DANDELION_TOKEN:
            raise DandelionSettingsException('You must set DANDELION_TOKEN in settings.py.')
